# Property

The Property commands are used to create and manage reinforcements and to assign properties to a part.
(See also Material commands and Section commands.) The Property commands are methods of a Part object.

## Create properties for Part

```{eval-rst}
.. autoclass:: abaqus.Property.PropertyPart.PropertyPart
    :members:
    :show-inheritance:

    .. autoclasstoc::
```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Property
        :recursive:
        :exclude: PropertyPart

    .. placeholder for empty members
```
